:hero: Univariate volatility modeling, bootstrapping, multiple comparison procedures and unit root tests.

.. image:: images/color-logo.svg
   :width: 33.3%
   :alt: arch logo

.. note::

  `Stable documentation <https://bashtage.github.io/arch/>`_ for the latest release
  is located at `doc <https://bashtage.github.io/arch/>`_.
  Documentation for `recent developments <https://bashtage.github.io/arch/devel/>`_
  is located at `devel <https://bashtage.github.io/arch/devel/>`_.

Introduction
============

The ARCH toolbox contains routines for:

- Univariate volatility models;
- Bootstrapping;
- Multiple comparison procedures;
- Unit root tests;
- Cointegration Testing and Estimation; and
- Long-run covariance estimation.

Future plans are to continue to expand this toolbox to include additional
routines relevant for the analysis of financial data.

.. toctree::
    :maxdepth: 2
    :hidden:

    Univariate Volatility Models <univariate/univariate>
    Bootstrapping <bootstrap/bootstrap>
    Multiple Comparison Problems <multiple-comparison/multiple-comparisons>
    Unit Root Tests and Cointegration Analysis <unitroot/unitroot>
    Long-run Covariance Estimation <covariance/covariance>
    API Reference <api>
    Change Log <changes>

Citation
========
This package should be cited using Zenodo. For example, for the 4.13 release,

.. [*] Kevin Sheppard (2021, March 3). bashtage/arch: Release 4.18 (Version v4.18).
   Zenodo. https://doi.org/10.5281/zenodo.593254

.. image:: https://zenodo.org/badge/doi/10.5281/zenodo.593254.svg
   :target: https://doi.org/10.5281/zenodo.593254

Index
=====

* :ref:`genindex`
* :ref:`modindex`
